@@ -59,14 +59,13 @@ class ImageLoader:
         ----------
         directory_root : str
             The directory of the dataset
-        levels_labels : int or sequence of ints, optional
-            The directory levels of the classes in the directory tree of the dataset.
         conditions_directories : None or sequence of Nones and sequences of ints, optional
             Conditions_directories can be a sequence or None (default is None). If it is a sequence, the l_th element
             of it is None or a sequence of ints. If the l_th element is a sequence of ints, it contains the conditions
-            of the tree l_th level that will be loaded. If the l_th element is None all conditions of the l_th level
-            will be loaded. If conditions_directories is None all conditions in all level will be loaded. It requires
-            to be a sequence if n_levels_directories is None.
+            of the l_th level that will be loaded. If the l_th element is None all conditions of the l_th level
+            will be loaded. If conditions_directories is None all conditions in all level will be loaded.
+        levels_labels : int or sequence of ints, optional
+            The directory levels of the classes in the directory tree of the dataset.
         order_outputs : str or sequence of str, optional
             The desired outputs of the self.load_batches_e(). Accepted values are "i", "l", "c","r", "a" or any
             combination of them like "ilcr", "ilr" (default is "il"). "i" stands for input samples, "l" for labels of
@@ -111,7 +110,7 @@ class ImageLoader:
         self.conditions_directories_names = []
         directory_root_l = self.directory_root
         while os.path.isdir(directory_root_l):
-            self.conditions_directories_names.append(os.listdir(directory_root_l))
+            self.conditions_directories_names.append(sorted(os.listdir(directory_root_l)))
             directory_root_l = os.path.join(directory_root_l, self.conditions_directories_names[l][0])
             l += 1
         self.L = self.n_levels_directories = l
@@ -260,7 +259,8 @@ class ImageLoader:
         print('self.n_samples =', self.n_samples)
         print('self.shifts =', self.shifts)
         print('self.n_conditions_directories =', self.n_conditions_directories)
-        # print('self.conditions_directories =', self.conditions_directories)
+        print('self.conditions_directories =', self.conditions_directories)
+        print('self.conditions_directories_names =', self.conditions_directories_names)
 
         self.levels_shifts_inter = []
         self.ranges_shifts_inter = []
@@ -268,7 +268,10 @@ class ImageLoader:
         self.levels_shifts_intra = []
         self.ranges_shifts_intra = []
 
-        if self.shifts is not None:
+        if self.shifts is None:
+            self.shifts_inter = None
+            self.shifts_intra = None
+        else:
             self.shifts.levels[self.shifts.levels < 0] += self.L
 
             for v in range(self.shifts.n_levels):
@@ -409,7 +412,7 @@ class ImageLoader:
 
         if self.return_inputs_eb:
 
-            self.inputs_eb = torch.empty(tuple(self.shape_batch.tolist()), dtype=tensor_0.dtype, device=self.device)
+            self.inputs_eb = torch.empty(tuple(self.shape_batch.tolist()), dtype=torch.float32, device=self.device)
         else:
             self.inputs_eb = None
 
@@ -502,7 +505,7 @@ class ImageLoader:
 
         self.b += 1
 
-        # if self.b < 1:
+        # if self.b < 2:
         if self.b < self.n_batches:
 
             if self.return_labels_eb:
