@@ -41,6 +41,8 @@ class ResNetNoLastLayer(torchvision.models.resnet.ResNet):
             kwargs = {'width_per_group': 64 * 2}
             super(ResNetNoLastLayer, self).__init__(torchvision.models.resnet.Bottleneck, [3, 4, 23, 3], **kwargs)
 
+        delattr(self, 'fc')
+
     def _forward_impl(self, x):
         x = self.conv1(x)
         x = self.bn1(x)
@@ -76,17 +78,15 @@ def load_resnet(name_resnet, last_layer=True, K=None, softmax=False, pretrained=
                 # Here the size of each output sample is set to K.
                 resnet.fc = torch.nn.Linear(num_ftrs, K)
         if isinstance(pretrained, str):
+            # TODO: what if the model was saved with cuda and is being loaded to cpu?
             state_dict = torch.load(pretrained)
             resnet.load_state_dict(state_dict)
     else:
         resnet = ResNetNoLastLayer(name_resnet)
 
         if isinstance(pretrained, str):
-            if (K is not None) and (K != resnet.fc.out_features):
-                num_ftrs = resnet.fc.in_features
-                resnet.fc = torch.nn.Linear(num_ftrs, K)
             state_dict = torch.load(pretrained)
-            resnet.load_state_dict(state_dict)
+
         elif pretrained:
             urls_resnets = {
                 'resnet18': 'https://download.pytorch.org/models/resnet18-5c106cde.pth',
@@ -100,8 +100,12 @@ def load_resnet(name_resnet, last_layer=True, K=None, softmax=False, pretrained=
                 'wide_resnet101_2': 'https://download.pytorch.org/models/wide_resnet101_2-32ee1156.pth',
             }
             state_dict = torch.hub.load_state_dict_from_url(urls_resnets[name_resnet])
-            resnet.load_state_dict(state_dict)
-        delattr(resnet, 'fc')
+        else:
+            raise TypeError('pretrained')
+
+        state_dict.pop('fc.weight')
+        state_dict.pop('fc.bias')
+        resnet.load_state_dict(state_dict)
 
     resnet = set_device(resnet, device)
 
